@@ -1,7 +1,7 @@
 use std::{
     collections::{BTreeMap, HashMap},
     fmt::Display,
-    path::{Path, PathBuf},
+    path::PathBuf,
     rc::Rc,
     time::Instant,
 };
@@ -27,8 +27,6 @@ use crate::{
     window_tab::CommonData,
 };
 
-const DEFAULT_RUN_TOML: &str = include_str!("../../defaults/run.toml");
-
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
 pub enum RunDebugMode {
     Run,
@@ -59,21 +57,6 @@ pub struct RunDebugConfigs {
     pub configs: Vec<RunDebugConfig>,
 }
 
-pub fn run_configs(workspace: Option<&Path>) -> Option<RunDebugConfigs> {
-    let workspace = workspace?;
-    let run_toml = workspace.join(".lapce").join("run.toml");
-    if !run_toml.exists() {
-        if !workspace.join(".lapce").exists() {
-            let _ = std::fs::create_dir_all(workspace.join(".lapce"));
-        }
-        let _ = std::fs::write(&run_toml, DEFAULT_RUN_TOML);
-        return None;
-    }
-    let content = std::fs::read_to_string(run_toml).ok()?;
-    let configs: RunDebugConfigs = toml::from_str(&content).ok()?;
-    Some(configs)
-}
-
 #[derive(Clone)]
 pub struct RunDebugData {
     pub active_term: RwSignal<Option<TermId>>,
