@@ -397,8 +397,8 @@ pub fn diff_show_more_section_view(
                 }),
                 label(|| "Expand All".to_string()).style(|s| s.margin_left(6.0)),
             ))
-            .on_event(EventListener::PointerDown, move |_| true)
-            .on_click(move |_event| {
+            .on_event_stop(EventListener::PointerDown, move |_| {})
+            .on_click_stop(move |_event| {
                 left_editor_view.update(|editor_view| {
                     if let EditorViewKind::Diff(diff_info) = editor_view {
                         expand_diff_lines(
@@ -419,10 +419,13 @@ pub fn diff_show_more_section_view(
                         );
                     }
                 });
-                true
             })
-            .style(|s| s.margin_left(10.0).height_pct(100.0).items_center())
-            .hover_style(|s| s.cursor(CursorStyle::Pointer)),
+            .style(|s| {
+                s.margin_left(10.0)
+                    .height_pct(100.0)
+                    .items_center()
+                    .hover(|s| s.cursor(CursorStyle::Pointer))
+            }),
             label(|| "|".to_string()).style(|s| s.margin_left(10.0)),
             stack((
                 svg(move || config.get().ui_svg(LapceIcons::FOLD_UP)).style(
@@ -435,8 +438,8 @@ pub fn diff_show_more_section_view(
                 ),
                 label(|| "Expand Up".to_string()).style(|s| s.margin_left(6.0)),
             ))
-            .on_event(EventListener::PointerDown, move |_| true)
-            .on_click(move |_event| {
+            .on_event_stop(EventListener::PointerDown, move |_| {})
+            .on_click_stop(move |_event| {
                 left_editor_view.update(|editor_view| {
                     if let EditorViewKind::Diff(diff_info) = editor_view {
                         expand_diff_lines(
@@ -457,10 +460,13 @@ pub fn diff_show_more_section_view(
                         );
                     }
                 });
-                true
             })
-            .style(move |s| s.margin_left(10.0).height_pct(100.0).items_center())
-            .hover_style(|s| s.cursor(CursorStyle::Pointer)),
+            .style(move |s| {
+                s.margin_left(10.0)
+                    .height_pct(100.0)
+                    .items_center()
+                    .hover(|s| s.cursor(CursorStyle::Pointer))
+            }),
             label(|| "|".to_string()).style(|s| s.margin_left(10.0)),
             stack((
                 svg(move || config.get().ui_svg(LapceIcons::FOLD_DOWN)).style(
@@ -473,8 +479,8 @@ pub fn diff_show_more_section_view(
                 ),
                 label(|| "Expand Down".to_string()).style(|s| s.margin_left(6.0)),
             ))
-            .on_event(EventListener::PointerDown, move |_| true)
-            .on_click(move |_event| {
+            .on_event_stop(EventListener::PointerDown, move |_| {})
+            .on_click_stop(move |_event| {
                 left_editor_view.update(|editor_view| {
                     if let EditorViewKind::Diff(diff_info) = editor_view {
                         expand_diff_lines(
@@ -495,10 +501,13 @@ pub fn diff_show_more_section_view(
                         );
                     }
                 });
-                true
             })
-            .style(move |s| s.margin_left(10.0).height_pct(100.0).items_center())
-            .hover_style(|s| s.cursor(CursorStyle::Pointer)),
+            .style(move |s| {
+                s.margin_left(10.0)
+                    .height_pct(100.0)
+                    .items_center()
+                    .hover(|s| s.cursor(CursorStyle::Pointer))
+            }),
         ))
         .style(move |s| {
             let config = config.get();
@@ -511,8 +520,8 @@ pub fn diff_show_more_section_view(
                     (section.visual_line * config.editor.line_height()) as f32
                         - viewport.get().y0 as f32,
                 )
+                .hover(|s| s.cursor(CursorStyle::Default))
         })
-        .hover_style(|s| s.cursor(CursorStyle::Default))
     };
 
     stack((
