@@ -7,7 +7,7 @@ use lapce_core::{
     command::MultiSelectionCommand,
     cursor::{ColPosition, Cursor, CursorMode},
     editor::Editor,
-    mode::{Mode, MotionMode},
+    mode::{Mode, MotionMode, VisualMode},
     movement::{LinePosition, Movement},
     register::Register,
     selection::{SelRegion, Selection},
@@ -411,6 +411,11 @@ pub fn move_cursor(
 ) {
     match cursor.mode {
         CursorMode::Normal(offset) => {
+            let count = if let Some(motion_mode) = cursor.motion_mode.as_ref() {
+                count.max(motion_mode.count())
+            } else {
+                count
+            };
             let (new_offset, horiz) = move_offset(
                 view,
                 offset,
@@ -470,7 +475,7 @@ pub fn move_cursor(
                 cursor.horiz.as_ref(),
                 count,
                 movement,
-                Mode::Visual,
+                Mode::Visual(VisualMode::Normal),
             );
             cursor.mode = CursorMode::Visual {
                 start,
