@@ -237,7 +237,7 @@ pub fn keymap_view(common: Rc<CommonData>) -> impl View {
                         .flex_grow(1.0)
                 }),
             ))
-            .on_click(move |_| {
+            .on_click_stop(move |_| {
                 let keymap = if let Some(keymap) = local_keymap.clone() {
                     keymap
                 } else {
@@ -253,7 +253,6 @@ pub fn keymap_view(common: Rc<CommonData>) -> impl View {
                 picker.keys.update(|keys| {
                     keys.clear();
                 });
-                true
             })
             .style(move |s| {
                 let config = config.get();
@@ -425,16 +424,29 @@ fn keyboard_picker_view(
             stack((
                 text("Save")
                     .style(move |s| {
+                        let config = config.get();
                         s.width(100.0)
                             .justify_center()
                             .padding_vert(8.0)
                             .border(1.0)
                             .border_radius(6.0)
                             .border_color(
-                                *config.get().get_color(LapceColor::LAPCE_BORDER),
+                                *config.get_color(LapceColor::LAPCE_BORDER),
                             )
+                            .hover(|s| {
+                                s.cursor(CursorStyle::Pointer).background(
+                                    *config.get_color(
+                                        LapceColor::PANEL_HOVERED_BACKGROUND,
+                                    ),
+                                )
+                            })
+                            .active(|s| {
+                                s.background(*config.get_color(
+                                    LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND,
+                                ))
+                            })
                     })
-                    .on_click(move |_| {
+                    .on_click_stop(move |_| {
                         let keymap = picker.keymap.get_untracked();
                         if let Some(keymap) = keymap {
                             let keys = picker.keys.get_untracked();
@@ -447,24 +459,10 @@ fn keyboard_picker_view(
                                     .collect::<Vec<KeyPress>>(),
                             );
                         }
-                        true
-                    })
-                    .hover_style(move |s| {
-                        s.cursor(CursorStyle::Pointer).background(
-                            *config
-                                .get()
-                                .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                        )
-                    })
-                    .active_style(move |s| {
-                        s.background(
-                            *config.get().get_color(
-                                LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND,
-                            ),
-                        )
                     }),
                 text("Cancel")
                     .style(move |s| {
+                        let config = config.get();
                         s.margin_left(20.0)
                             .width(100.0)
                             .justify_center()
@@ -472,26 +470,23 @@ fn keyboard_picker_view(
                             .border(1.0)
                             .border_radius(6.0)
                             .border_color(
-                                *config.get().get_color(LapceColor::LAPCE_BORDER),
+                                *config.get_color(LapceColor::LAPCE_BORDER),
                             )
+                            .hover(|s| {
+                                s.cursor(CursorStyle::Pointer).background(
+                                    *config.get_color(
+                                        LapceColor::PANEL_HOVERED_BACKGROUND,
+                                    ),
+                                )
+                            })
+                            .active(|s| {
+                                s.background(*config.get_color(
+                                    LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND,
+                                ))
+                            })
                     })
-                    .on_click(move |_| {
+                    .on_click_stop(move |_| {
                         picker.keymap.set(None);
-                        true
-                    })
-                    .hover_style(move |s| {
-                        s.cursor(CursorStyle::Pointer).background(
-                            *config
-                                .get()
-                                .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                        )
-                    })
-                    .active_style(move |s| {
-                        s.background(
-                            *config.get().get_color(
-                                LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND,
-                            ),
-                        )
                     }),
             ))
             .style(move |s| {
@@ -516,7 +511,7 @@ fn keyboard_picker_view(
         }),
     )
     .keyboard_navigatable()
-    .on_event(EventListener::KeyDown, move |event| {
+    .on_event_stop(EventListener::KeyDown, move |event| {
         if let Event::KeyDown(key_event) = event {
             if let Some(keypress) = KeyPressData::keypress(key_event) {
                 picker.keys.update(|keys| {
@@ -532,9 +527,8 @@ fn keyboard_picker_view(
                 })
             }
         }
-        true
     })
-    .on_event(EventListener::KeyUp, move |event| {
+    .on_event_stop(EventListener::KeyUp, move |event| {
         if let Event::KeyUp(_key_event) = event {
             picker.keys.update(|keys| {
                 if let Some((_last_key, last_key_confirmed)) = keys.last_mut() {
@@ -542,7 +536,6 @@ fn keyboard_picker_view(
                 }
             })
         }
-        true
     })
     .style(move |s| {
         s.absolute()
