@@ -38,7 +38,7 @@ use crate::{
         CommandExecuted, CommandKind, InternalCommand, LapceCommand, WindowCommand,
     },
     db::LapceDb,
-    debug::{run_configs, RunDebugMode},
+    debug::{RunDebugConfigs, RunDebugMode},
     editor::{
         location::{EditorLocation, EditorPosition},
         EditorData,
@@ -55,6 +55,8 @@ use crate::{
 pub mod item;
 pub mod kind;
 
+const DEFAULT_RUN_TOML: &str = include_str!("../../defaults/run.toml");
+
 #[derive(Clone, PartialEq, Eq)]
 pub enum PaletteStatus {
     Inactive,
@@ -736,8 +738,8 @@ impl PaletteData {
         self.items.set(items);
     }
 
-    fn get_run_configs(&self) {
-        let configs = run_configs(self.common.workspace.path.as_deref());
+    fn set_run_configs(&self, content: String) {
+        let configs: Option<RunDebugConfigs> = toml::from_str(&content).ok();
         if configs.is_none() {
             if let Some(path) = self.workspace.path.as_ref() {
                 let path = path.join(".lapce").join("run.toml");
@@ -746,8 +748,8 @@ impl PaletteData {
                     .send(InternalCommand::OpenFile { path });
             }
         }
-        let executed_run_configs = self.executed_run_configs.borrow();
 
+        let executed_run_configs = self.executed_run_configs.borrow();
         let mut items = Vec::new();
         if let Some(configs) = configs.as_ref() {
             for config in &configs.configs {
@@ -797,6 +799,35 @@ impl PaletteData {
             .set(items.into_iter().map(|(_, item)| item).collect());
     }
 
+    fn get_run_configs(&self) {
+        if let Some(workspace) = self.common.workspace.path.as_deref() {
+            let run_toml = workspace.join(".lapce").join("run.toml");
+            let (doc, new_doc) = self.main_split.get_doc(run_toml.clone());
+            if !new_doc {
+                let content = doc.buffer.with_untracked(|b| b.to_string());
+                self.set_run_configs(content);
+            } else {
+                let loaded = doc.loaded;
+                let palette = self.clone();
+                self.common.scope.create_effect(move |prev_loaded| {
+                    if prev_loaded == Some(true) {
+                        return true;
+                    }
+
+                    let loaded = loaded.get();
+                    if loaded {
+                        let content = doc.buffer.with_untracked(|b| b.to_string());
+                        if content.is_empty() {
+                            doc.reload(Rope::from(DEFAULT_RUN_TOML), false);
+                        }
+                        palette.set_run_configs(content);
+                    }
+                    loaded
+                });
+            }
+        }
+    }
+
     fn get_color_themes(&self) {
         let config = self.common.config.get_untracked();
         let items = config
@@ -841,18 +872,17 @@ impl PaletteData {
             .iter()
             .map(|lang| PaletteItem {
                 content: PaletteItemContent::Language {
-                    name: lang.to_owned().to_owned(),
+                    name: lang.to_string(),
                 },
-                filter_text: lang.to_owned().to_owned(),
+                filter_text: lang.to_string(),
                 score: 0,
                 indices: Vec::new(),
             })
             .collect();
         if let Some(editor) = self.main_split.active_editor.get_untracked() {
             let doc = editor.view.doc.get_untracked();
-            let language = doc.syntax.with_untracked(|syntax| {
-                syntax.language.get_message().unwrap_or("")
-            });
+            let language =
+                doc.syntax.with_untracked(|syntax| syntax.language.name());
             self.preselect_matching(&items, language);
         }
         self.items.set(items);
@@ -985,11 +1015,11 @@ impl PaletteData {
                     self.common.lapce_command.send(cmd.clone());
                 }
                 PaletteItemContent::Workspace { workspace } => {
-                    self.common
-                        .window_command
-                        .send(WindowCommand::SetWorkspace {
+                    self.common.window_common.window_command.send(
+                        WindowCommand::SetWorkspace {
                             workspace: workspace.clone(),
-                        });
+                        },
+                    );
                 }
                 PaletteItemContent::Reference { location, .. } => {
                     self.common.internal_command.send(
@@ -999,15 +1029,15 @@ impl PaletteData {
                     );
                 }
                 PaletteItemContent::SshHost { host } => {
-                    self.common
-                        .window_command
-                        .send(WindowCommand::SetWorkspace {
+                    self.common.window_common.window_command.send(
+                        WindowCommand::SetWorkspace {
                             workspace: LapceWorkspace {
                                 kind: LapceWorkspaceType::RemoteSSH(host.clone()),
                                 path: None,
                                 last_open: 0,
                             },
-                        });
+                        },
+                    );
                 }
                 PaletteItemContent::DocumentSymbol { range, .. } => {
                     let editor = self.main_split.active_editor.get_untracked();
@@ -1107,15 +1137,15 @@ impl PaletteData {
         } else if self.kind.get_untracked() == PaletteKind::SshHost {
             let input = self.input.with_untracked(|input| input.input.clone());
             let ssh = SshHost::from_string(&input);
-            self.common
-                .window_command
-                .send(WindowCommand::SetWorkspace {
+            self.common.window_common.window_command.send(
+                WindowCommand::SetWorkspace {
                     workspace: LapceWorkspace {
                         kind: LapceWorkspaceType::RemoteSSH(ssh),
                         path: None,
                         last_open: 0,
                     },
-                });
+                },
+            );
         }
     }
 
