@@ -290,38 +290,35 @@ fn debug_processes(
                         s.apply_if(!is_hovered.get() && !is_active(), |s| s.hide())
                     }),
                 ))
-                .on_click(move |_| {
+                .on_click_stop(move |_| {
                     local_terminal.debug.active_term.set(Some(term_id));
                     local_terminal.focus_terminal(term_id);
-                    true
                 })
-                .on_event(EventListener::PointerEnter, move |_| {
+                .on_event_stop(EventListener::PointerEnter, move |_| {
                     is_hovered.set(true);
-                    true
                 })
-                .on_event(EventListener::PointerLeave, move |_| {
+                .on_event_stop(EventListener::PointerLeave, move |_| {
                     is_hovered.set(false);
-                    true
                 })
                 .style(move |s| {
+                    let config = config.get();
                     s.padding_vert(6.0)
                         .width_pct(100.0)
                         .items_center()
                         .apply_if(is_active(), |s| {
                             s.background(
                                 *config
-                                    .get()
                                     .get_color(LapceColor::PANEL_CURRENT_BACKGROUND),
                             )
                         })
-                })
-                .hover_style(move |s| {
-                    s.cursor(CursorStyle::Pointer).background(
-                        (*config
-                            .get()
-                            .get_color(LapceColor::PANEL_HOVERED_BACKGROUND))
-                        .with_alpha_factor(0.3),
-                    )
+                        .hover(|s| {
+                            s.cursor(CursorStyle::Pointer).background(
+                                (*config.get_color(
+                                    LapceColor::PANEL_HOVERED_BACKGROUND,
+                                ))
+                                .with_alpha_factor(0.3),
+                            )
+                        })
                 })
             },
         )
@@ -407,7 +404,7 @@ fn variables_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                         text(format!(" = {}", node.item.value().unwrap_or("")))
                             .style(move |s| s.apply_if(reference > 0, |s| s.hide())),
                     ))
-                    .on_click(move |_| {
+                    .on_click_stop(move |_| {
                         if reference > 0 {
                             let dap = local_terminal.get_active_dap(false);
                             if let Some(dap) = dap {
@@ -426,22 +423,19 @@ fn variables_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                                 }
                             }
                         }
-                        true
                     })
                     .style(move |s| {
                         s.items_center()
                             .padding_right(10.0)
                             .padding_left((level * 10) as f32)
                             .min_width_pct(100.0)
-                    })
-                    .hover_style(move |s| {
-                        s.apply_if(reference > 0, |s| {
-                            s.background(
-                                *config
-                                    .get()
-                                    .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                            )
-                        })
+                            .hover(|s| {
+                                s.apply_if(reference > 0, |s| {
+                                    s.background(*config.get().get_color(
+                                        LapceColor::PANEL_HOVERED_BACKGROUND,
+                                    ))
+                                })
+                            })
                     })
                 },
             )
@@ -463,17 +457,19 @@ fn debug_stack_frames(
     let expanded = stack_trace.expanded;
     stack((
         container(label(move || thread_id.to_string()))
-            .on_click(move |_| {
+            .on_click_stop(move |_| {
                 expanded.update(|expanded| {
                     *expanded = !*expanded;
                 });
-                true
             })
-            .style(|s| s.padding_horiz(10.0).min_width_pct(100.0))
-            .hover_style(move |s| {
-                s.cursor(CursorStyle::Pointer).background(
-                    *config.get().get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                )
+            .style(move |s| {
+                s.padding_horiz(10.0).min_width_pct(100.0).hover(move |s| {
+                    s.cursor(CursorStyle::Pointer).background(
+                        *config
+                            .get()
+                            .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
+                    )
+                })
             }),
         list(
             move || {
@@ -502,12 +498,14 @@ fn debug_stack_frames(
                 let source_path = format!("{source_path}:{}", frame.line);
 
                 container(stack((
-                    label(move || frame.name.clone()).hover_style(move |s| {
-                        s.background(
-                            *config
-                                .get()
-                                .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                        )
+                    label(move || frame.name.clone()).style(move |s| {
+                        s.hover(|s| {
+                            s.background(
+                                *config
+                                    .get()
+                                    .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
+                            )
+                        })
                     }),
                     label(move || source_path.clone()).style(move |s| {
                         s.margin_left(10.0)
@@ -516,7 +514,7 @@ fn debug_stack_frames(
                             .apply_if(!has_source, |s| s.hide())
                     }),
                 )))
-                .on_click(move |_| {
+                .on_click_stop(move |_| {
                     if let Some(path) = full_path.clone() {
                         internal_command.send(InternalCommand::JumpToLocation {
                             location: EditorLocation {
@@ -537,23 +535,22 @@ fn debug_stack_frames(
                         dap_id,
                         frame_id: frame.id,
                     });
-                    true
                 })
                 .style(move |s| {
+                    let config = config.get();
                     s.padding_left(20.0)
                         .padding_right(10.0)
                         .min_width_pct(100.0)
                         .apply_if(!has_source, |s| {
-                            s.color(*config.get().get_color(LapceColor::EDITOR_DIM))
+                            s.color(*config.get_color(LapceColor::EDITOR_DIM))
+                        })
+                        .hover(|s| {
+                            s.background(
+                                *config
+                                    .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
+                            )
+                            .apply_if(has_source, |s| s.cursor(CursorStyle::Pointer))
                         })
-                })
-                .hover_style(move |s| {
-                    s.background(
-                        *config
-                            .get()
-                            .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                    )
-                    .apply_if(has_source, |s| s.cursor(CursorStyle::Pointer))
                 })
             },
         )
@@ -679,12 +676,12 @@ fn breakpoints_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                             || false,
                             config,
                         )
-                        .on_event(EventListener::PointerDown, |_| true),
+                        .on_event_stop(EventListener::PointerDown, |_| {}),
                         checkbox(move || breakpoint.active, config)
                             .style(|s| {
                                 s.margin_right(6.0).cursor(CursorStyle::Pointer)
                             })
-                            .on_click(move |_| {
+                            .on_click_stop(move |_| {
                                 breakpoints.update(|breakpoints| {
                                     if let Some(breakpoints) =
                                         breakpoints.get_mut(&full_path)
@@ -696,7 +693,6 @@ fn breakpoints_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                                         }
                                     }
                                 });
-                                true
                             }),
                         text(format!("{file_name}:{}", breakpoint.line + 1)).style(
                             move |s| {
@@ -723,15 +719,18 @@ fn breakpoints_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                                 .apply_if(folder_empty, |s| s.hide())
                         }),
                     ))
-                    .style(|s| s.items_center().padding_horiz(10.0).width_pct(100.0))
-                    .hover_style(move |s| {
-                        s.background(
-                            *config
-                                .get()
-                                .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
+                    .style(move |s| {
+                        s.items_center().padding_horiz(10.0).width_pct(100.0).hover(
+                            |s| {
+                                s.background(
+                                    *config.get().get_color(
+                                        LapceColor::PANEL_HOVERED_BACKGROUND,
+                                    ),
+                                )
+                            },
                         )
                     })
-                    .on_click(move |_| {
+                    .on_click_stop(move |_| {
                         internal_command.send(InternalCommand::JumpToLocation {
                             location: EditorLocation {
                                 path: full_path_for_jump.clone(),
@@ -741,7 +740,6 @@ fn breakpoints_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                                 same_editor_tab: false,
                             },
                         });
-                        true
                     })
                 },
             )
