@@ -384,7 +384,7 @@ pub fn settings_view(
             label(move || k.clone())
                 .style(move |s| s.text_ellipsis().padding_left(margin)),
         )
-        .on_click(move |_| {
+        .on_click_stop(move |_| {
             if let Some(pos) = pos() {
                 ensure_visible.set(
                     settings_content_size
@@ -393,31 +393,27 @@ pub fn settings_view(
                         .with_origin(pos.get_untracked()),
                 );
             }
-            true
         })
         .style(move |s| {
-            s.padding_horiz(20.0).width_pct(100.0).apply_if(
-                kind == current_kind.get(),
-                |s| {
+            let config = config.get();
+            s.padding_horiz(20.0)
+                .width_pct(100.0)
+                .apply_if(kind == current_kind.get(), |s| {
+                    s.background(
+                        *config.get_color(LapceColor::PANEL_CURRENT_BACKGROUND),
+                    )
+                })
+                .hover(|s| {
+                    s.cursor(CursorStyle::Pointer).background(
+                        *config.get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
+                    )
+                })
+                .active(|s| {
                     s.background(
                         *config
-                            .get()
-                            .get_color(LapceColor::PANEL_CURRENT_BACKGROUND),
+                            .get_color(LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND),
                     )
-                },
-            )
-        })
-        .hover_style(move |s| {
-            s.cursor(CursorStyle::Pointer).background(
-                *config.get().get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-            )
-        })
-        .active_style(move |s| {
-            s.background(
-                *config
-                    .get()
-                    .get_color(LapceColor::PANEL_HOVERED_ACTIVE_BACKGROUND),
-            )
+                })
         })
     };
 
@@ -648,7 +644,7 @@ fn settings_item_view(settings_data: SettingsData, item: SettingsItem) -> impl V
                     let field = field.clone();
                     let local_item_string = item_string.clone();
                     label(move || local_item_string.clone())
-                        .on_click(move |_| {
+                        .on_click_stop(move |_| {
                             current_value.set(item_string.clone());
                             if let Ok(value) = serde::Serialize::serialize(
                                 &item_string,
@@ -657,15 +653,15 @@ fn settings_item_view(settings_data: SettingsData, item: SettingsItem) -> impl V
                                 LapceConfig::update_file(&kind, &field, value);
                             }
                             expanded.set(false);
-                            true
                         })
-                        .style(|s| s.text_ellipsis().padding_horiz(10.0))
-                        .hover_style(move |s| {
-                            s.cursor(CursorStyle::Pointer).background(
-                                *config
-                                    .get()
-                                    .get_color(LapceColor::PANEL_HOVERED_BACKGROUND),
-                            )
+                        .style(move |s| {
+                            s.text_ellipsis().padding_horiz(10.0).hover(|s| {
+                                s.cursor(CursorStyle::Pointer).background(
+                                    *config.get().get_color(
+                                        LapceColor::PANEL_HOVERED_BACKGROUND,
+                                    ),
+                                )
+                            })
                         })
                 };
                 container_box(
@@ -692,11 +688,10 @@ fn settings_item_view(settings_data: SettingsData, item: SettingsItem) -> impl V
                             )
                             .style(|s| s.padding_right(4.0)),
                         ))
-                        .on_click(move |_| {
+                        .on_click_stop(move |_| {
                             expanded.update(|expanded| {
                                 *expanded = !*expanded;
                             });
-                            true
                         })
                         .style(move |s| {
                             s.items_center()
@@ -744,11 +739,10 @@ fn settings_item_view(settings_data: SettingsData, item: SettingsItem) -> impl V
                             }),
                         ))
                         .keyboard_navigatable()
-                        .on_event(EventListener::FocusLost, move |_| {
+                        .on_event_stop(EventListener::FocusLost, move |_| {
                             if expanded.get_untracked() {
                                 expanded.set(false);
                             }
-                            true
                         })
                         .style(move |s| {
                             s.absolute()
@@ -828,11 +822,10 @@ fn settings_item_view(settings_data: SettingsData, item: SettingsItem) -> impl V
                     ))
                     .style(|s| s.items_center()),
                 )
-                .on_click(move |_| {
+                .on_click_stop(move |_| {
                     checked.update(|checked| {
                         *checked = !*checked;
                     });
-                    true
                 })
                 .style(|s| {
                     s.absolute()
@@ -1080,12 +1073,11 @@ fn color_section_list(
                         let local_key = key.clone();
                         let local_kind = kind.clone();
                         text("Reset")
-                            .on_click(move |_| {
+                            .on_click_stop(move |_| {
                                 LapceConfig::reset_setting(
                                     &format!("color-theme.{local_kind}"),
                                     &local_key,
                                 );
-                                true
                             })
                             .style(move |s| {
                                 let config = config.get();
@@ -1117,13 +1109,13 @@ fn color_section_list(
                                         *config.get_color(LapceColor::LAPCE_BORDER),
                                     )
                                     .apply_if(same, |s| s.hide())
-                            })
-                            .active_style(move |s| {
-                                s.background(
-                                    *config
-                                        .get()
-                                        .get_color(LapceColor::PANEL_BACKGROUND),
-                                )
+                                    .active(|s| {
+                                        s.background(
+                                            *config.get_color(
+                                                LapceColor::PANEL_BACKGROUND,
+                                            ),
+                                        )
+                                    })
                             })
                     },
                 ))
