@@ -14,10 +14,11 @@ pub fn web_link(
     internal_command: Listener<InternalCommand>,
 ) -> impl View {
     label(text)
-        .on_click(move |_| {
+        .on_click_stop(move |_| {
             internal_command.send(InternalCommand::OpenWebUri { uri: uri() });
-            true
         })
-        .base_style(move |s| s.color(color()))
-        .hover_style(move |s| s.cursor(CursorStyle::Pointer))
+        .base_style(move |s| {
+            s.color(color())
+                .hover(move |s| s.cursor(CursorStyle::Pointer))
+        })
 }
