@@ -35,6 +35,52 @@ pub enum CursorMode {
     Insert(Selection),
 }
 
+struct RegionsIter<'c> {
+    cursor_mode: &'c CursorMode,
+    idx: usize,
+}
+
+impl<'c> Iterator for RegionsIter<'c> {
+    type Item = (usize, usize);
+
+    fn next(&mut self) -> Option<Self::Item> {
+        match self.cursor_mode {
+            &CursorMode::Normal(offset) => (self.idx == 0).then(|| {
+                self.idx = 1;
+                (offset, offset)
+            }),
+            &CursorMode::Visual { start, end, .. } => (self.idx == 0).then(|| {
+                self.idx = 1;
+                (start, end)
+            }),
+            CursorMode::Insert(selection) => {
+                let next = selection
+                    .regions()
+                    .get(self.idx)
+                    .map(|&SelRegion { start, end, .. }| (start, end));
+
+                if next.is_some() {
+                    self.idx += 1;
+                }
+
+                next
+            }
+        }
+    }
+
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        let total_len = match self.cursor_mode {
+            CursorMode::Normal(_) | CursorMode::Visual { .. } => 1,
+            CursorMode::Insert(selection) => selection.len(),
+        };
+        let len = total_len - self.idx;
+
+        (len, Some(len))
+    }
+}
+
+impl<'c> ExactSizeIterator for RegionsIter<'c> {}
+
 impl CursorMode {
     pub fn offset(&self) -> usize {
         match &self {
@@ -53,6 +99,15 @@ impl CursorMode {
             }
         }
     }
+
+    pub fn regions_iter(
+        &self,
+    ) -> impl ExactSizeIterator<Item = (usize, usize)> + '_ {
+        RegionsIter {
+            cursor_mode: self,
+            idx: 0,
+        }
+    }
 }
 
 impl Cursor {
@@ -89,6 +144,12 @@ impl Cursor {
         self.mode.start_offset()
     }
 
+    pub fn regions_iter(
+        &self,
+    ) -> impl ExactSizeIterator<Item = (usize, usize)> + '_ {
+        self.mode.regions_iter()
+    }
+
     pub fn is_normal(&self) -> bool {
         matches!(&self.mode, CursorMode::Normal(_))
     }
@@ -104,7 +165,7 @@ impl Cursor {
     pub fn get_mode(&self) -> Mode {
         match &self.mode {
             CursorMode::Normal(_) => Mode::Normal,
-            CursorMode::Visual { .. } => Mode::Visual,
+            CursorMode::Visual { mode, .. } => Mode::Visual(*mode),
             CursorMode::Insert(_) => Mode::Insert,
         }
     }
