@@ -2,7 +2,7 @@ use std::{collections::HashSet, path::Path, str::FromStr};
 
 use anyhow::Result;
 use once_cell::sync::Lazy;
-use strum_macros::{AsRefStr, Display, EnumMessage, EnumString};
+use strum_macros::{AsRefStr, AsStaticStr, Display, EnumMessage, EnumString};
 use tracing::{debug, error};
 use tree_sitter::TreeCursor;
 
@@ -140,6 +140,7 @@ struct CommentProperties {
     Debug,
     Display,
     AsRefStr,
+    AsStaticStr,
     EnumString,
     EnumMessage,
     Default,
@@ -853,16 +854,13 @@ const LANGUAGES: &[SyntaxProperties] = &[
             multi_line_end: Some("=#"),
         },
 
-        #[cfg(feature = "lang-julia")]
         tree_sitter: Some(TreeSitterProperties {
-            language: tree_sitter_julia::language,
-            highlight: Some(include_str!("../queries/julia/highlights.scm")),
-            injection: Some(include_str!("../queries/julia/injections.scm")),
+            language: None,
+            grammar: None,
+            query: None,
             code_lens: (DEFAULT_CODE_LENS_LIST, DEFAULT_CODE_LENS_IGNORE_LIST),
             sticky_headers: &[],
         }),
-        #[cfg(not(feature = "lang-julia"))]
-        tree_sitter: None,
     },
     SyntaxProperties {
         id: LapceLanguage::Kotlin,
@@ -1055,11 +1053,10 @@ const LANGUAGES: &[SyntaxProperties] = &[
 
         comment: comment_properties!("//"),
 
-        #[cfg(feature = "lang-php")]
         tree_sitter: Some(TreeSitterProperties {
-            language: tree_sitter_php::language,
-            highlight: Some(tree_sitter_php::HIGHLIGHT_QUERY),
-            injection: Some(tree_sitter_php::INJECTIONS_QUERY),
+            language: None,
+            grammar: None,
+            query: None,
             code_lens: (
                 &[
                     "program",
@@ -1084,8 +1081,6 @@ const LANGUAGES: &[SyntaxProperties] = &[
             ),
             sticky_headers: &[],
         }),
-        #[cfg(not(feature = "lang-php"))]
-        tree_sitter: None,
     },
     SyntaxProperties {
         id: LapceLanguage::Prisma,
@@ -1207,16 +1202,13 @@ const LANGUAGES: &[SyntaxProperties] = &[
 
         comment: comment_properties!("#"),
 
-        #[cfg(feature = "lang-ruby")]
         tree_sitter: Some(TreeSitterProperties {
-            language: tree_sitter_ruby::language,
-            highlight: Some(tree_sitter_ruby::HIGHLIGHT_QUERY),
-            injection: None,
+            language: None,
+            grammar: None,
+            query: None,
             code_lens: (DEFAULT_CODE_LENS_LIST, DEFAULT_CODE_LENS_IGNORE_LIST),
             sticky_headers: &["module", "class", "method", "do_block"],
         }),
-        #[cfg(not(feature = "lang-ruby"))]
-        tree_sitter: None,
     },
     SyntaxProperties {
         id: LapceLanguage::Rust,
@@ -1523,12 +1515,12 @@ const LANGUAGES: &[SyntaxProperties] = &[
 ];
 
 impl LapceLanguage {
-    const HIGHLIGHTS_QUERIES_FILE_NAME: &str = "highlights.scm";
-    const HIGHLIGHTS_INJECTIONS_FILE_NAME: &str = "injections.scm";
+    const HIGHLIGHTS_QUERIES_FILE_NAME: &'static str = "highlights.scm";
+    const HIGHLIGHTS_INJECTIONS_FILE_NAME: &'static str = "injections.scm";
     #[cfg(unix)]
-    const SYSTEM_GRAMMARS_DIRECTORY: &str = "/usr/lib";
+    const SYSTEM_GRAMMARS_DIRECTORY: &'static str = "/usr/lib";
     #[cfg(unix)]
-    const SYSTEM_QUERIES_DIRECTORY: &str = "/usr/share/tree-sitter/grammars";
+    const SYSTEM_QUERIES_DIRECTORY: &'static str = "/usr/share/tree-sitter/grammars";
 
     pub fn from_path(path: &Path) -> LapceLanguage {
         Self::from_path_raw(path).unwrap_or(LapceLanguage::Plaintext)
@@ -1563,9 +1555,10 @@ impl LapceLanguage {
     pub fn languages() -> Vec<&'static str> {
         let mut langs = vec![];
         for l in LANGUAGES {
-            if let Some(lang) = strum::EnumMessage::get_message(&l.id) {
-                langs.push(lang)
-            }
+            langs.push(
+                strum::EnumMessage::get_message(&l.id)
+                    .unwrap_or(strum::AsStaticRef::as_static(&l.id)),
+            )
         }
         langs
     }
@@ -1585,6 +1578,11 @@ impl LapceLanguage {
         l
     }
 
+    pub fn name(&self) -> &'static str {
+        strum::EnumMessage::get_message(self)
+            .unwrap_or(strum::AsStaticRef::as_static(self))
+    }
+
     fn tree_sitter(&self) -> Option<TreeSitterProperties> {
         self.properties().tree_sitter
     }
